==> aws-java-sdk-workspaces-1.10.45-sources.jar: com/amazonaws/services/workspaces/model/WorkspaceDirectoryType.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.workspaces.model;

/**
 * 
 */
public enum WorkspaceDirectoryType {

    SIMPLE_AD("SIMPLE_AD"),
    AD_CONNECTOR("AD_CONNECTOR");

    private String value;

    private WorkspaceDirectoryType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return WorkspaceDirectoryType corresponding to the value
     */
    public static WorkspaceDirectoryType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if ("SIMPLE_AD".equals(value)) {
            return SIMPLE_AD;
        } else if ("AD_CONNECTOR".equals(value)) {
            return AD_CONNECTOR;
        } else {
            throw new IllegalArgumentException("Cannot create enum from "
                    + value + " value!");
        }
    }
}

==> aws-java-sdk-workspaces-1.11.13-sources.jar: com/amazonaws/services/workspaces/model/WorkspaceDirectoryType.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.workspaces.model;

/**
 * 
 */
public enum WorkspaceDirectoryType {

    SIMPLE_AD("SIMPLE_AD"),
    AD_CONNECTOR("AD_CONNECTOR");

    private String value;

    private WorkspaceDirectoryType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return WorkspaceDirectoryType corresponding to the value
     */
    public static WorkspaceDirectoryType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        }

        for (WorkspaceDirectoryType enumEntry : WorkspaceDirectoryType.values()) {
            if (enumEntry.toString().equals(value)) {
                return enumEntry;
            }
        }

        throw new IllegalArgumentException("Cannot create enum from " + value
                + " value!");
    }
}
